pub struct EventPreciseCoverageDeltaUpdate {
pub timestamp: f64,
pub occasion: String,
pub result: Vec<ScriptCoverage>,
}Expand description
Reports coverage delta since the last poll (either from an event like this, or from
takePreciseCoverage for the current isolate. May only be sent if precise code
coverage has been started. This event can be trigged by the embedder to, for example,
trigger collection of coverage data immediately at a certain point in time.
preciseCoverageDeltaUpdate
Fields
timestamp: f64Monotonically increasing time (in seconds) when the coverage update was taken in the backend.
occasion: StringIdentifier for distinguishing coverage events.
result: Vec<ScriptCoverage>Coverage data for the current isolate.
Implementations
Sourceimpl EventPreciseCoverageDeltaUpdate
impl EventPreciseCoverageDeltaUpdate
pub const IDENTIFIER: &'static str = "Profiler.preciseCoverageDeltaUpdate"